==> lhcsmapi-1.4.58.tar.gz: lhcsmapi-1.4.58/lhcsmapi/gui/pc/R60AFgcPmSearchBaseModule.py <==
from typing import List, Tuple

from lhcsmapi.gui.pc.FgcPmSearchBaseModule import FgcPmSearchBaseModule
from lhcsmapi.metadata.SignalMetadata import SignalMetadata
from lhcsmapi.pyedsl.QueryBuilder import QueryBuilder


def query_pm_convert_pc_to_circuit_name(start_time, end_time, circuit_names: List[str]) -> List[Tuple[str, int]]:
    """ Method querying FGC PM source and timestamp tuple and taking only those corresponding to the given circuits

    :param start_time: start time for a query
    :param end_time: end time for a query
    :param circuit_names: list of circuit names for which
    :return: a list of PM source and timestamp tuples corresponding to circuit names
    """
    # Query PM for the specified period of time
    source_timestamp_df = QueryBuilder().with_pm() \
        .with_duration(t_start=start_time, t_end=end_time) \
        .with_query_parameters(system='FGC', className='lhc_self_pmd', source='*') \
        .event_query().df

    # Keep only sources corresponding to circuit names
    pc_names = [SignalMetadata.get_circuit_signal_database_metadata('60A', circuit_name, 'PC', 'PM')['source']
                for circuit_name in circuit_names]
    mask = source_timestamp_df['source'].isin(pc_names)
    source_timestamp_mask_df = source_timestamp_df[mask]

    # Convert PC names to circuit names
    output = []
    for index, row in source_timestamp_mask_df.iterrows():
        pc_name = row['source']
        pc_name_split = pc_name.split('.')
        circuit_name = '%s.%s' % (pc_name_split[-2], pc_name_split[-1])
        output.append((circuit_name, row['timestamp']))

    return output


class R60AFgcPmSearchBaseModule(FgcPmSearchBaseModule):
    """ A class with methods to search for 60A FGC PM events to fill-in a search field in the FGC PM search module.

    """

    def find_fgc_pm_entries_with_qps(self, start_time, end_time, circuit_name):
        """ Method finding FGC PM entries with QPS for a given time range and circuit name

        :param start_time: start time for the query
        :param end_time: end time for the query
        :param circuit_name: circuit name
        :return: a list of FGC source and timestamp tuples
        """
        circuit_names_all = SignalMetadata.get_circuit_names('60A')
        circuit_names = filter(lambda x: circuit_name in x, circuit_names_all)

        self.lbl_search.value = 'Querying PM for FGC events'
        self.progress_search.layout.visibility = 'visible'
        self.progress_search.max = 1
        self.progress_search.description = ''

        output = query_pm_convert_pc_to_circuit_name(start_time, end_time, circuit_names)

        self.lbl_search.value = 'Query completed'
        self.progress_search.layout.visibility = 'visible'
        self.progress_search.value = 1
        self.progress_search.description = ''

        return output

==> lhcsmapi-1.4.70.tar.gz: lhcsmapi-1.4.70/lhcsmapi/gui/pc/R60AFgcPmSearchBaseModule.py <==
from typing import List, Tuple

from lhcsmapi.gui.pc.FgcPmSearchBaseModule import FgcPmSearchBaseModule, \
    convert_source_timestamp_to_circuit_name_timestamp
from lhcsmapi.metadata.SignalMetadata import SignalMetadata
from lhcsmapi.pyedsl.QueryBuilder import QueryBuilder


def query_pm_convert_pc_to_circuit_name(start_time, end_time, circuit_names: List[str]) -> List[Tuple[str, int]]:
    """ Method querying FGC PM source and timestamp tuple and taking only those corresponding to the given circuits

    :param start_time: start time for a query
    :param end_time: end time for a query
    :param circuit_names: list of circuit names for which
    :return: a list of PM source and timestamp tuples corresponding to circuit names
    """
    # Query PM for the specified period of time
    source_timestamp_df = QueryBuilder().with_pm() \
        .with_duration(t_start=start_time, t_end=end_time) \
        .with_query_parameters(system='FGC', className='lhc_self_pmd', source='*') \
        .event_query().keep_sources_for_circuit_names('60A', circuit_names, 'PC', start_time).df

    # Convert PC names to circuit names
    return convert_source_timestamp_to_circuit_name_timestamp(source_timestamp_df)


class R60AFgcPmSearchBaseModule(FgcPmSearchBaseModule):
    """ A class with methods to search for 60A FGC PM events to fill-in a search field in the FGC PM search module.

    """

    def find_fgc_pm_entries_with_qps(self, start_time, end_time, circuit_name):
        """ Method finding FGC PM entries with QPS for a given time range and circuit name

        :param start_time: start time for the query
        :param end_time: end time for the query
        :param circuit_name: circuit name
        :return: a list of FGC source and timestamp tuples
        """
        circuit_names_all = SignalMetadata.get_circuit_names('60A')
        circuit_names = list(filter(lambda x: circuit_name in x, circuit_names_all))

        self.lbl_search.value = 'Querying PM for FGC events'
        self.progress_search.layout.visibility = 'visible'
        self.progress_search.max = 1
        self.progress_search.description = ''

        output = query_pm_convert_pc_to_circuit_name(start_time, end_time, circuit_names)

        self.lbl_search.value = 'Query completed'
        self.progress_search.layout.visibility = 'visible'
        self.progress_search.value = 1
        self.progress_search.description = ''

        return output
